@@ -1615,6 +1615,9 @@ def prepare_sig_field(
         except KeyError:
             fields = form['/Fields'] = generic.ArrayObject()
 
+        if len(fields) > 0:
+            sig_field_name = 'Signature' + str(len(fields) + 1)
+
         candidates = enumerate_sig_fields_in(
             fields, with_name=sig_field_name, refs_seen=set()
         )
