@@ -7,7 +7,7 @@ in PDF files, and for handling PDF-specific document signing needs.
 from .functions import async_sign_pdf, sign_pdf
 
 from .pdf_cms import SimpleSigner, ExternalSigner
-from .pdf_signer import PdfSignatureMetadata, PdfTimeStamper
+from .pdf_signer import PdfSignatureMetadata, PdfTimeStamper, PdfSigner
 
 from .constants import (
     DEFAULT_MD,
@@ -18,6 +18,7 @@ __all__ = [
     'ExternalSigner',
     'PdfSignatureMetadata',
     'PdfTimeStamper',
+    'PdfSigner',
     'sign_pdf',
     'async_sign_pdf',
     'DEFAULT_MD'
