@@ -4,8 +4,13 @@ from .pdf_embedded import (
 )
 from .dss import DocumentSecurityStore
 
+from .ltv import (
+    get_timestamp_chain,
+)
+
 __all__ = [
     'read_certification_data',
+    'get_timestamp_chain',
     'DocumentSecurityStore'
 ]
 
