@@ -27,7 +27,7 @@ __all__ = [
     'enumerate_ocsp_certs',
 ]
 
-dataclass
+@dataclass
 class VRI:
     """
     VRI dictionary as defined in PAdES / ISO 32000-2.
